@@ -24,7 +24,8 @@ from oslo_messaging import exceptions
 base_opts = [
     cfg.IntOpt('rpc_conn_pool_size', default=30,
                deprecated_group='DEFAULT',
-               help='Size of RPC connection pool.'),
+               help='Size of RPC connection pool.',
+               min=1),
     cfg.IntOpt('conn_pool_min_size', default=2,
                help='The pool size limit for connections expiration policy'),
     cfg.IntOpt('conn_pool_ttl', default=1200,
