@@ -28,7 +28,7 @@ import time
 from urllib import parse
 import uuid
 
-from amqp import exceptions as amqp_exec
+from amqp import exceptions as amqp_ex
 import kombu
 import kombu.connection
 import kombu.entity
@@ -106,9 +106,11 @@ rabbit_opts = [
                 ),
     cfg.FloatOpt('kombu_reconnect_delay',
                  default=1.0,
+                 min=0.0,
+                 max=amqpdriver.ACK_REQUEUE_EVERY_SECONDS_MAX * 0.9,
                  deprecated_group='DEFAULT',
-                 help='How long to wait before reconnecting in response to an '
-                      'AMQP consumer cancel notification.'),
+                 help='How long to wait (in seconds) before reconnecting in '
+                      'response to an AMQP consumer cancel notification.'),
     cfg.StrOpt('kombu_compression',
                help="EXPERIMENTAL: Possible values are: gzip, bz2. If not "
                     "set compression will not be used. This option may not "
@@ -174,7 +176,8 @@ rabbit_opts = [
                'or dead-lettered (if a DLX exchange has been configured) '
                'Used only when rabbit_quorum_queue is enabled, '
                'Default 0 which means dont set a limit.'),
-    cfg.IntOpt('rabbit_quroum_max_memory_length',
+    cfg.IntOpt('rabbit_quorum_max_memory_length',
+               deprecated_name='rabbit_quroum_max_memory_length',
                default=0,
                help='By default all messages are maintained in memory '
                'if a quorum queue grows in length it can put memory '
@@ -182,7 +185,8 @@ rabbit_opts = [
                'of messages in the quorum queue. '
                'Used only when rabbit_quorum_queue is enabled, '
                'Default 0 which means dont set a limit.'),
-    cfg.IntOpt('rabbit_quroum_max_memory_bytes',
+    cfg.IntOpt('rabbit_quorum_max_memory_bytes',
+               deprecated_name='rabbit_quroum_max_memory_bytes',
                default=0,
                help='By default all messages are maintained in memory '
                'if a quorum queue grows in length it can put memory '
@@ -191,12 +195,16 @@ rabbit_opts = [
                'Used only when rabbit_quorum_queue is enabled, '
                'Default 0 which means dont set a limit.'),
     cfg.IntOpt('rabbit_transient_queues_ttl',
-               min=1,
+               min=0,
                default=1800,
                help='Positive integer representing duration in seconds for '
                     'queue TTL (x-expires). Queues which are unused for the '
                     'duration of the TTL are automatically deleted. The '
-                    'parameter affects only reply and fanout queues.'),
+                    'parameter affects only reply and fanout queues. Setting '
+                    '0 as value will disable the x-expires. If doing so, '
+                    'make sure you have a rabbitmq policy to delete the '
+                    'queues or you deployment will create an infinite number '
+                    'of queue over time.'),
     cfg.IntOpt('rabbit_qos_prefetch_count',
                default=0,
                help='Specifies the number of messages to prefetch. Setting to '
@@ -207,7 +215,7 @@ rabbit_opts = [
                "considered down if heartbeat's keep-alive fails "
                "(0 disables heartbeat)."),
     cfg.IntOpt('heartbeat_rate',
-               default=2,
+               default=3,
                help='How often times during the heartbeat_timeout_threshold '
                'we check the heartbeat.'),
     cfg.BoolOpt('direct_mandatory_flag',
@@ -411,7 +419,7 @@ class Consumer(object):
                       conn.connection_id, self.queue_name)
             try:
                 self.queue.declare()
-            except amqp_exec.PreconditionFailed as err:
+            except amqp_ex.PreconditionFailed as err:
                 # NOTE(hberaud): This kind of exception may be triggered
                 # when a control exchange is shared between services and
                 # when services try to create it with configs that differ
@@ -449,6 +457,14 @@ class Consumer(object):
                           'Queue: [%(queue)s], '
                           'error message: [%(err_str)s]', info)
                 time.sleep(interval)
+                if self.queue_arguments.get('x-queue-type') == 'quorum':
+                    # Before re-declare queue, try to delete it
+                    # This is helping with issue #2028384
+                    # NOTE(amorin) we need to make sure the connection is
+                    # established again, because when an error occur, the
+                    # connection is closed.
+                    conn.ensure_connection()
+                    self.queue.delete()
                 self.queue.declare()
             else:
                 raise
@@ -491,6 +507,24 @@ class Consumer(object):
                                    nowait=self.nowait)
             else:
                 raise
+        except amqp_ex.InternalError as exc:
+            if self.queue_arguments.get('x-queue-type') == 'quorum':
+                # Before re-consume queue, try to delete it
+                # This is helping with issue #2028384
+                if exc.code == 541:
+                    LOG.warning('Queue %s seems broken, will try delete it '
+                                'before starting over.', self.queue.name)
+                    # NOTE(amorin) we need to make sure the connection is
+                    # established again, because when an error occur, the
+                    # connection is closed.
+                    conn.ensure_connection()
+                    self.queue.delete()
+                    self.declare(conn)
+                    self.queue.consume(callback=self._callback,
+                                       consumer_tag=str(tag),
+                                       nowait=self.nowait)
+            else:
+                raise
 
     def cancel(self, tag):
         LOG.trace('ConsumerBase.cancel: canceling %s', tag)
@@ -649,6 +683,8 @@ class Connection(object):
             # if it was already monkey patched by eventlet/greenlet.
             global threading
             threading = _utils.stdlib_threading
+            amqpdriver.threading = _utils.stdlib_threading
+            amqpdriver.queue = _utils.stdlib_queue
 
         self.direct_mandatory_flag = driver_conf.direct_mandatory_flag
 
@@ -835,8 +871,8 @@ class Connection(object):
     def _get_quorum_configurations(self, driver_conf):
         """Get the quorum queue configurations"""
         delivery_limit = driver_conf.rabbit_quorum_delivery_limit
-        max_memory_length = driver_conf.rabbit_quroum_max_memory_length
-        max_memory_bytes = driver_conf.rabbit_quroum_max_memory_bytes
+        max_memory_length = driver_conf.rabbit_quorum_max_memory_length
+        max_memory_bytes = driver_conf.rabbit_quorum_max_memory_bytes
         return QuorumMemConfig(delivery_limit, max_memory_length,
                                max_memory_bytes)
 
@@ -1198,7 +1234,7 @@ class Connection(object):
                             ConnectionRefusedError,
                             OSError,
                             kombu.exceptions.OperationalError,
-                            amqp_exec.ConnectionForced) as exc:
+                            amqp_ex.ConnectionForced) as exc:
                         LOG.info("A recoverable connection/channel error "
                                  "occurred, trying to reconnect: %s", exc)
                         self.ensure_connection()
@@ -1400,7 +1436,7 @@ class Connection(object):
         if not (exchange.passive or exchange.name in self._declared_exchanges):
             try:
                 exchange(self.channel).declare()
-            except amqp_exec.PreconditionFailed as err:
+            except amqp_ex.PreconditionFailed as err:
                 # NOTE(hberaud): This kind of exception may be triggered
                 # when a control exchange is shared between services and
                 # when services try to create it with configs that differ
@@ -1509,6 +1545,8 @@ class Connection(object):
                                          passive=True)
         options = oslo_messaging.TransportOptions(
             at_least_once=self.direct_mandatory_flag)
+
+        LOG.debug('Sending direct to %s', msg_id)
         self._ensure_publishing(self._publish_and_raises_on_missing_exchange,
                                 exchange, msg, routing_key=msg_id,
                                 transport_options=options)
@@ -1522,6 +1560,8 @@ class Connection(object):
             durable=self.durable,
             auto_delete=self.amqp_auto_delete)
 
+        LOG.debug('Sending topic to %s with routing_key %s', exchange_name,
+                  topic)
         self._ensure_publishing(self._publish, exchange, msg,
                                 routing_key=topic, timeout=timeout,
                                 retry=retry,
@@ -1534,6 +1574,7 @@ class Connection(object):
                                          durable=False,
                                          auto_delete=True)
 
+        LOG.debug('Sending fanout to %s_fanout', topic)
         self._ensure_publishing(self._publish, exchange, msg, retry=retry)
 
     def notify_send(self, exchange_name, topic, msg, retry=None, **kwargs):
