@@ -17,7 +17,7 @@ import fixtures
 import oslo_messaging
 from oslo_messaging.notify import log_handler
 from oslo_messaging.tests import utils as test_utils
-from six.moves import mock
+from unittest import mock
 
 
 class PublishErrorsHandlerTestCase(test_utils.BaseTestCase):
